Module union

Module union 

Array for sum types.

Structs

DenseLayout
The dense union layout.
DenseUnionArray
A dense union array.
SparseLayout
The sparse union layout.
SparseUnionArray
A sparse union array.
UnionArray
Array for sum types.
UnionArrayIntoIter
State required to iterate over union arrays

Traits

EnumVariant
The array data for enum variants stored in union array wrappers.
TypeIdIterator
Types that return a constructed enum by advancing iterator(s) of variants of a union array given the type_id for the variant.
UnionArrayIterators
Types that may be consumed to construct iterators of union array variants.
UnionArrayType
Union array types.
UnionType
Different types of union layouts.

Type Aliases

NA
Indicates that a UnionType generic is not applicable.