UnionArrayIterators

Trait UnionArrayIterators 

pub trait UnionArrayIterators {
    type VariantIterators: TypeIdIterator;

    // Required method
    fn new_variant_iters(self) -> Self::VariantIterators;
}
Types that may be consumed to construct iterators of union array variants.

Required Associated Types

type VariantIterators: TypeIdIterator

Type holding the variant iterators that may be advanced to get the value for a type_id.

Required Methods

fn new_variant_iters(self) -> Self::VariantIterators

Constructs VariantIterators by consuming Self.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors