NA

Type Alias NA 

pub type NA = SparseLayout;
Indicates that a UnionType generic is not applicable.

This is used instead to prevent confusion in code because we don’t have default types for generic associated types.

This still shows up as SparseLayout in documentation but there is no way to prevent that.

Aliased Type

pub struct NA;