Logical array support.
Modules
- box
- Box support via logical arrays.
- chrono
chrono - Chrono support via logical arrays.
- map
map - Map arrays via logical arrays.
- uuid
uuid - Uuid support via logical arrays.
Structs
- Logical
Array - An array for
LogicalArrayTypeitems, that are stored in Arrow arrays, but convertable from and to theirself via this array wrapper.
Traits
- Logical
Array Type - Types that can be stored in Arrow arrays, but require mapping via
LogicalArray.