pub struct KeyValueArray<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> { /* private fields */ }Available on crate feature
map only.Trait Implementations
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> Clone for KeyValueArray<K, V, Buffer>
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> Clone for KeyValueArray<K, V, Buffer>
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> Default for KeyValueArray<K, V, Buffer>
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> Default for KeyValueArray<K, V, Buffer>
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> Extend<KeyValue<K, V>> for KeyValueArray<K, V, Buffer>
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> Extend<KeyValue<K, V>> for KeyValueArray<K, V, Buffer>
Sourcefn extend<_I: IntoIterator<Item = KeyValue<K, V>>>(&mut self, iter: _I)
fn extend<_I: IntoIterator<Item = KeyValue<K, V>>>(&mut self, iter: _I)
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> From<KeyValueArray<K, V, Buffer>> for Vec<Arc<dyn Array>>
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> From<KeyValueArray<K, V, Buffer>> for Vec<Arc<dyn Array>>
Sourcefn from(value: KeyValueArray<K, V, Buffer>) -> Self
fn from(value: KeyValueArray<K, V, Buffer>) -> Self
Converts to this type from the input type.
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> From<Vec<Arc<dyn Array>>> for KeyValueArray<K, V, Buffer>
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> From<Vec<Arc<dyn Array>>> for KeyValueArray<K, V, Buffer>
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> FromIterator<KeyValue<K, V>> for KeyValueArray<K, V, Buffer>
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> FromIterator<KeyValue<K, V>> for KeyValueArray<K, V, Buffer>
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> IntoIterator for KeyValueArray<K, V, Buffer>where
<K as ArrayType<K>>::Array<Buffer, NA, NA>: IntoIterator<Item = K>,
<V as ArrayType<V>>::Array<Buffer, NA, NA>: IntoIterator<Item = V>,
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> IntoIterator for KeyValueArray<K, V, Buffer>where
<K as ArrayType<K>>::Array<Buffer, NA, NA>: IntoIterator<Item = K>,
<V as ArrayType<V>>::Array<Buffer, NA, NA>: IntoIterator<Item = V>,
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> Length for KeyValueArray<K, V, Buffer>
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> Length for KeyValueArray<K, V, Buffer>
Sourceimpl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> StructArrayTypeFields for KeyValueArray<K, V, Buffer>
impl<K: ArrayType<K>, V: ArrayType<V>, Buffer: BufferType> StructArrayTypeFields for KeyValueArray<K, V, Buffer>